@@ -1,5 +1,5 @@
 package Bio::ToolBox::GeneTools;
-our $VERSION = '1.52';
+our $VERSION = '1.53';
 
 =head1 NAME
 
@@ -45,7 +45,7 @@ gene, transcript, and exons. For example,
 
 Depending upon how the SeqFeatures were generated or defined, subfeatures 
 may or may not be defined or be obvious. For example, UTRs or introns may 
-not be present. Furthermore, the primary_tag or type may not follow 
+not be present. Furthermore, the C<primary_tag> or type may not follow 
 Sequence Ontology terms. Regular expressions are deployed to handle 
 varying naming schemes and exceptions.
 
@@ -71,28 +71,28 @@ Import all of the methods.
 
 =item :exon
 
-Import all of the exon methods, including get_exons(), get_alt_exons(), 
-get_common_exons(), get_uncommon_exons(), and get_alt_common_exons().
+Import all of the exon methods, including L</get_exons>, L</get_alt_exons>, 
+L</get_common_exons>, L</get_uncommon_exons>, and L</get_alt_common_exons>.
 
 =item :intron
 
-Import all of the intron methods, including get_introns(), get_alt_introns(), 
-get_common_introns(), get_uncommon_introns(), and get_alt_common_introns().
+Import all of the intron methods, including L</get_introns>, L</get_alt_introns>, 
+L</get_common_introns>, L</get_uncommon_introns>, and L</get_alt_common_introns>.
 
 =item :transcript
 
-Import the transcript related methods, including get_transcripts(), 
-get_transcript_length(), and collapse_transcripts().
+Import the transcript related methods, including L</get_transcripts>, 
+L</get_transcript_length>, and L</collapse_transcripts>.
 
 =item :cds
 
-Import the CDS pertaining methods, including is_coding(), get_cds(), 
-get_cdsStart(), get_cdsEnd(), get_transcript_cds_length(), and get_utrs().
+Import the CDS pertaining methods, including L</is_coding>, L</get_cds>, 
+L</get_cdsStart>, L</get_cdsEnd>, L</get_transcript_cds_length>, and L</get_utrs>.
 
 =item :export
 
-Import all of the export methods, including gff_string(), gtf_string(), 
-and ucsc_string();
+Import all of the export methods, including L</gff_string>, L</gtf_string>, 
+and L</ucsc_string>;
 
 =back
 
@@ -102,32 +102,41 @@ Functions to get a list of exons from a gene or transcript
 
 =over 4
 
-=item get_exons($gene)
+=item get_exons
 
-=item get_exons($transcript)
+	my @exons = get_exons($gene);
+	my @exons = get_exons($transcript);
 
 This will return an array or array reference of all the exon subfeatures in 
 the SeqFeature object, either gene or transcript. No discrimination whether 
 they are used once or more than once. Non-defined exons can be assembled from 
 CDS and/or UTR subfeatures. Exons are sorted by start coordinate.
 
-=item get_alt_exons($gene)
+=item get_alt_exons
+
+	my @alternate_exons = get_alt_exons($gene);
 
 This will return an array or array reference of all the exon subfeatures for 
 a multi-transcript gene that are used only once in all of the transcripts.
 
-=item get_common_exons($gene)
+=item get_common_exons
+
+	my @common_exons = get_common_exons($gene);
 
 This will return an array or array reference of all the exon subfeatures for 
 a multi-transcript gene that are used in all of the transcripts.
 
-=item get_uncommon_exons($gene)
+=item get_uncommon_exons
+
+	my @uncommon_exons = get_uncommon_exons($gene);
 
 This will return an array or array reference of all the exon subfeatures for 
 a multi-transcript gene that are used in some of the transcripts, i.e. more 
 than one but not all.
 
-=item get_alt_common_exons($gene)
+=item get_alt_common_exons
+
+	my %exon_hash = get_alt_common_exons($gene);
 
 This will return a hash reference with several keys, including "common", 
 "uncommon", and each of the transcript IDs. Each key value is an array 
@@ -151,32 +160,41 @@ elements are generated for each intron.
 
 =over 4
 
-=item get_introns($gene)
+=item get_introns
 
-=item get_introns($transcript)
+	my @introns = get_introns($gene);
+	my @introns = get_introns($transcript);
 
 This will return an array or array reference of all the intron subfeatures in 
 the SeqFeature object, either gene or transcript. No discrimination whether 
 they are used once or more than once. Non-defined introns can be assembled from 
-CDS and/or UTR subfeatures. Introns are sorted by start coordinate.
+CDS andE<sol>or UTR subfeatures. Introns are sorted by start coordinate.
 
-=item get_alt_introns($gene)
+=item get_alt_introns
+
+	my @alternate_introns = get_alt_introns($gene);
 
 This will return an array or array reference of all the intron subfeatures for 
 a multi-transcript gene that are used only once in all of the transcripts.
 
-=item get_common_introns($gene)
+=item get_common_introns
+
+	my @common_introns = get_common_introns($gene);
 
 This will return an array or array reference of all the intron subfeatures for 
 a multi-transcript gene that are used in all of the transcripts.
 
-=item get_uncommon_introns($gene)
+=item get_uncommon_introns
+
+	my @uncommon_introns = get_uncommon_introns($gene);
 
 This will return an array or array reference of all the intron subfeatures for 
 a multi-transcript gene that are used in some of the transcripts, i.e. more 
 than one but not all.
 
-=item get_alt_common_introns($gene)
+=item get_alt_common_introns
+
+	my %intron_hash = get_alt_common_introns($gene);
 
 This will return a hash reference with several keys, including "common", 
 "uncommon", and each of the transcript IDs. Each key value is an array 
@@ -198,14 +216,17 @@ gene SeqFeature.
 
 =over 4
 
-=item get_transcripts($gene)
+=item get_transcripts
+
+	my @transcripts = get_transcripts($gene);
 
 Returns an array or array reference of the transcripts associated with a 
 gene feature.
 
-=item collapse_transcripts($gene)
+=item collapse_transcripts
 
-=item collapse_transcripts($transcript1, $transcript2, ...)
+	my $new_transcript = collapse_transcripts($gene);
+	my $new_transcript = collapse_transcripts($transcript1, $transcript2);
 
 This method will collapse all of the transcripts associated with a gene 
 SeqFeature into a single artificial transcript, merging exons as necessary 
@@ -213,10 +234,14 @@ to maximize exon length and minimize introns. This is useful when
 performing, for example, RNASeq analysis on genes. A single SeqFeature 
 transcript object is returned containing the merged exon subfeatures. 
 
-=item get_transcript_length($transcript)
+Pass either a gene or a list of transcripts to collapse.
+
+=item get_transcript_length
+
+	my $length = get_transcript_length($transcript);
 
 Calculates and returns the transcribed length of a transcript, i.e 
-the sum of its exon lengths. Warning! If you pass a gene object, you 
+the sum of its exon lengths. B<Warning!> If you pass a gene object, you 
 will get the maximum of all transcript exon lengths, which may not be 
 what you anticipate!
 
@@ -229,22 +254,31 @@ mRNA transcripts.
 
 =over 4
 
-=item is_coding($gene)
+=item is_coding
 
-=item is_coding($transcript)
+	if( is_coding($transcript) ) {
+		# do something
+	}
 
-This method will return a boolean value if the passed transcript object 
+This method will return a boolean value (1 or 0) if the passed transcript object 
 appears to be a coding transcript. GFF and GTF files are not always immediately 
 clear about the type of transcript; there are (unfortunately) multiple ways 
-to encode the feature as a protein coding transcript: primary_tag, source_tag, 
-attribute, CDS subfeatures, etc. This method tries to determine this.
+to encode the feature as a protein coding transcript: C<primary_tag>, 
+C<source_tag>, GFF attribute, presence of CDS subfeatures, etc. 
+This method checks all of these possibilities. B<Note>: If you pass a 
+multi-transcript gene, only one transcript need to be coding to pass a true 
+value.
 
-=item get_cds($transcript)
+=item get_cds
+
+	my @cds = get_cds($transcript);
 
 Returns the CDS subfeatures of the given transcript, if they are 
 defined. Returns either an array or array reference.
 
-=item get_cdsStart($transcript)
+=item get_cdsStart
+
+	my $start = get_cdsStart($trancript);
 
 Returns the start coordinate of the CDS for the given transcript.
 Note that this is the leftmost (smallest) coordinate of the CDS 
@@ -252,74 +286,102 @@ and not necessarily the coordinate of the start codon, similar to
 what the UCSC gene tables report. Use the transcript strand to 
 determine the 5' end.
 
-=item get_cdsEnd($transcript)
+=item get_cdsEnd
+
+	my $end = get_cdsEnd($trancript);
 
 Returns the stop coordinate of the CDS for the given transcript.
-Note that this is the rightmost (largest) coordinate of the CDS 
+B<Note> that this is the rightmost (largest) coordinate of the CDS 
 and not necessarily the coordinate of the stop codon, similar to 
 what the UCSC gene tables report. Use the transcript strand to 
-determine the 3' end.
+determine which is the C<3'> and C<5'> end.
 
-=item get_start_codon($transcript)
+=item get_start_codon
+
+	my $start_codon = get_start_codon($trancript);
 
 Returns a SeqFeature object representing the start codon. If one is 
-not defined in the hierarchy, then a new object is created.
+not explicitly defined in the hierarchy, then a new object is generated.
 
-=item get_stop_codon($transcript)
+=item get_stop_codon
+
+	my $stop_codon = get_stop_codon($transcript);
 
 Returns a SeqFeature object representing the stop codon. If one is 
-not defined in the hierarchy, then a new object is created. Not that 
+not defined in the hierarchy, then a new object is created. <BNote> that 
 this assumes that the stop codon is inclusive to the defined CDS.
 
-=item get_transcript_cds_length($transcript)
+=item get_transcript_cds_length
+
+	my $length = get_transcript_cds_length($transcript);
 
 Calculates and returns the length of the coding sequence for a 
 transcript, i.e. the sum of the CDS lengths.
 
-=item get_utrs($transcript)
+=item get_utrs
 
-Returns both 5' and 3' untranslated regions of the transcript. If these are 
-not defined in the SeqFeature subfeature hierarchy, then they will be calculated 
-from the exon and CDS subfeatures, if available. Non-coding transcripts will not 
-return anything. 
+	my @utrs = get_utrs($trancript);
 
-=item get_5p_utrs($transcript)
+Returns both C<5'> and C<3'> untranslated regions of the transcript. If these are 
+not defined in the SeqFeature subfeature hierarchy, then the coordinates will be 
+determined from from the exon and CDS subfeatures, if available, and new SeqFeature 
+objects generated. Non-coding transcripts will not return anything. 
 
-Returns only the 5' untranslated regions of the transcript.
+=item get_5p_utrs
+
+	my @5p_utrs = get_5p_utrs($trancript);
+
+Returns only the C<5'> untranslated regions of the transcript.
 
 =item get_3p_utrs($transcript)
 
-Returns only the 3' untranslated regions of the transcript.
+	my @3p_utrs = get_3p_utrs($trancript);
+
+Returns only the C<3'> untranslated regions of the transcript.
 
 =back
 
 =head2 Export methods
 
-These methods are used for exporting a gene and/or transcript model into 
+These methods are used for exporting a gene andE<sol>or transcript model into 
 a text string based on the specified format. 
 
 =over 4
 
-=item gff_string($gene)
+=item gff_string
+
+	my $string .= gff_string($gene, 1);
+	my $string .= gff_string($transcript, 1);
 
 This is just a convenience method. SeqFeature objects based on 
 L<Bio::SeqFeature::Lite>, L<Bio::DB::SeqFeature>, or L<Bio::ToolBox::SeqFeature>
-have a gff_string() method, and this will simply call that method. SeqFeature 
+have a C<gff_string> method, and this will simply call that method. SeqFeature 
 objects that do not have this method will, of course, cause the script to 
 terminate. 
 
-L<Bio::ToolBox::Data::Feature> also provides a gff_string method.
+Pass the seqfeature object and a boolean value to recursively append all 
+subfeatures (e.g. exons) to the string. In most cases, this will generate a 
+GFF3-style string.
 
-=item gtf_string($gene)
+L<Bio::ToolBox::Data::Feature> also provides a simplified gff_string method.
+
+=item gtf_string
+
+	my $string .= gtf_string($gene);
+	my $string .= gtf_string($transcript);
 
 This will export a gene or transcript model as a series of GTF formatted 
 text lines, following the defined Gene Transfer Format (also known as GFF 
 version 2.5). It will ensure that each feature is properly tagged with the 
-gene_id and transcript_id attributes. 
+C<gene_id> and C<transcript_id> attributes. 
 
-=item ucsc_string($gene)
+This method will automatically recurse through all subfeatures.
 
-This will export a gene or transcript model as a refFlat formatted gene 
+=item ucsc_string
+
+	my $string = ucsc_string($gene);
+
+This will export a gene or transcript model as a refFlat formatted Gene 
 Prediction line (11 columns). See L<http://genome.ucsc.edu/FAQ/FAQformat.html#format9>
 for details. Multiple transcript genes are exported as multiple text lines 
 concatenated together.
@@ -332,17 +394,19 @@ These methods are used to filter genes.
 
 =over 4
 
-=item filter_transcript_support_level($gene)
+=item filter_transcript_support_level
 
-=item filter_transcript_support_level($gene, $level)
+	my $new_gene = filter_transcript_support_level($gene, 'best2');
+	my @good_transcripts = filter_transcript_support_level(\@transcripts);
 
 This will filter a gene object for transcripts that match or exceed the 
 provided transcript support level. This assumes that the transcripts 
 contain the attribute tag 'transcript_support_level', which are present in 
 Ensembl provided GFF3 and GTF annotation files. The values are a digit (1-5), 
 or 'NA', where 1 is experimentally supported and 5 is entirely predicted 
-with no experimental evidence. See for example 
-L<Ensembl TSL glossary entry|http://uswest.ensembl.org/info/website/glossary.html>. 
+with no experimental evidence. See 
+L<Ensembl TSL glossary entry|http://www.ensembl.org/info/website/glossary.html> 
+for details. 
 
 Pass a gene SeqFeature object with one or more transcript subfeatures. 
 Alternatively, an array reference of transcripts could be passed as well.
@@ -355,13 +419,13 @@ A level may be provided as a second argument. The default is 'best'.
 
 Only the transcripts with the highest existing value will be retained.
 
-=item best<digit>
+=item bestE<lt>digitE<gt>
 
 All transcripts up to the indicated level are retained. For example, 
 'best3' would indicate that transcripts with support levels 1, 2, and 3 
 would be retained. 
 
-=item <digit>
+=item E<lt>digitE<gt>
 
 Only transcripts at the given level are retained.
 
@@ -382,6 +446,11 @@ transcripts is returned.
 
 =back
 
+=head1 SEE ALSO
+
+L<Bio::ToolBox::SeqFeature>, L<Bio::ToolBox::parser::ucsc>, L<Bio::Tools::GFF>,
+L<Bio::SeqFeature::Lite>, L<Bio::DB::SeqFeature>
+
 =cut
 
 use strict;
@@ -752,7 +821,7 @@ sub _get_alt_common_things {
 sub get_transcripts {
 	my $gene = shift;
 	confess "not a SeqFeature object!" unless ref($gene) =~ /seqfeature/i;
-	return $gene if ( $gene->primary_tag !~ /gene/i and 
+	return $gene if ( $gene->primary_tag !~ /gene$/i and 
 		$gene->primary_tag =~ /rna|transcript/i);
 	my @transcripts;
 	my @exons;
@@ -808,6 +877,15 @@ sub collapse_transcripts {
 		push @exons, @e;
 	}
 	
+	# check that we have exons - weirdo files may just have CDS!!!????
+	unless (@exons) {
+		foreach my $t (@transcripts) {
+			my @e = get_cds($t);
+			push @exons, @e;
+		}
+	}
+	return unless (@exons);
+	
 	# sort all the exons
 	my @sorted = 	map { $_->[0] }
 					sort { $a->[1] <=> $b->[1] or $a->[2] <=> $b->[2] }
@@ -867,7 +945,7 @@ sub collapse_transcripts {
 sub get_transcript_length {
 	my $transcript = shift;
 	confess "not a SeqFeature object!" unless ref($transcript) =~ /seqfeature/i;
-	if ($transcript->primary_tag =~ /gene/i) {
+	if ($transcript->primary_tag =~ /gene$/i) {
 		# someone passed a gene object!!!!
 		my @lengths;
 		foreach my $t (get_transcripts($transcript)) {
@@ -890,7 +968,7 @@ sub get_transcript_length {
 sub is_coding {
 	my $transcript = shift;
 	return unless $transcript;
-	if ($transcript->primary_tag =~ /gene/i) {
+	if ($transcript->primary_tag =~ /gene$/i) {
 		# someone passed a gene, check its subfeatures
 		my $code_potential = 0;
 		foreach ($transcript->get_SeqFeatures) {
@@ -948,8 +1026,13 @@ sub get_cdsStart {
 	else {
 		# stop codons may or may not be not included
 		my $codon = get_stop_codon($transcript);
-		return $codon->start < $cds->[0]->start ? 
-			$codon->start : $cds->[0]->start;
+		if ($codon) {
+			return $codon->start < $cds->[0]->start ? 
+				$codon->start : $cds->[0]->start;
+		}
+		else {
+			return $cds->[0]->start;
+		}
 	}
 }
 
@@ -959,8 +1042,12 @@ sub get_cdsEnd {
 	return unless $cds;
 	if ($transcript->strand >= 0) {
 		my $codon = get_stop_codon($transcript);
-		return $codon->end > $cds->[-1]->end ? 
-			$codon->end : $cds->[-1]->end;
+		if ($codon) {
+			return $codon->end > $cds->[-1]->end ? $codon->end : $cds->[-1]->end;
+		}
+		else {
+			return $cds->[-1]->end;
+		}
 	}
 	else {
 		return $cds->[-1]->end;
@@ -1244,7 +1331,7 @@ sub gtf_string {
 	confess "not a SeqFeature object!" unless ref($feature) =~ /seqfeature/i;
 	
 	# process a gene 
-	if ($feature->primary_tag =~ /gene/i and not defined $gene) {
+	if ($feature->primary_tag =~ /gene$/i and not defined $gene) {
 		my $string;
 		foreach my $t (get_transcripts($feature)) {
 			$string .= gtf_string($t, $feature);
@@ -1324,7 +1411,7 @@ sub ucsc_string {
 	my @ucsc_list;
 	
 	# process according to type
-	if ($feature->primary_tag =~ /gene/i) {
+	if ($feature->primary_tag =~ /gene$/i) {
 		# a gene object, we will need to process it's transcript subfeatures
 		foreach my $transcript (get_transcripts($feature)) {
 			my $ucsc = _process_ucsc_transcript($transcript, $feature);
@@ -1371,7 +1458,7 @@ sub filter_transcript_support_level {
 	
 	# get transcripts
 	my @transcripts;
-	if (ref($gene) =~ /seqfeature/i and $gene->primary_tag =~ /gene/i) {
+	if (ref($gene) =~ /seqfeature/i and $gene->primary_tag =~ /gene$/i) {
 		@transcripts = get_transcripts($gene);
 	}
 	elsif (ref($gene) eq 'ARRAY') {
